# -*- coding: utf-8 -*-

from django.utils.translation import gettext_lazy as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from . import admin
from . import models


@plugin_pool.register_plugin
class TrackingCodePlugin(admin.TrackingCodeSettingAdmin, CMSPluginBase):
    model = models.TrackingCodeSetting
    module = _("matomo")
    name = _("tracking code")
    render_template = "matomo/tracking_code.html"
    allow_children = False

    def render(self, context, instance, placeholder):
        if instance.status == 0:
            return context

        self.render_template = instance.template_name

        plugin_order = instance.placeholder.get_plugin_tree_order(instance.language)

        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'plugin_order': plugin_order,
        })
        return context


@plugin_pool.register_plugin
class TagManagerPlugin(admin.TagManagerSettingAdmin, CMSPluginBase):
    model = models.TagManagerSetting
    module = _("matomo")
    name = _("tag manager")
    render_template = "matomo/tag_manager.html"
    allow_children = False

    def render(self, context, instance, placeholder):
        if instance.status == 0:
            return context

        self.render_template = instance.template_name

        plugin_order = instance.placeholder.get_plugin_tree_order(instance.language)

        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'plugin_order': plugin_order,
        })
        return context
