# -*- coding: utf-8 -*-

from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy as _

from cms.models.pluginmodel import CMSPlugin
from thx.core.models import UserModel, DateModel, StatusModel, OrderedModel, CleanModel


class TrackingCodeSetting(CMSPlugin, CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    title = models.CharField(
        max_length=255,
        verbose_name=_('title')
    )
    slug = models.SlugField(
        max_length=255,
        verbose_name=_('slug')
    )
    template_name = models.CharField(
        max_length=255,
        choices=settings.MATOMO_TRACKING_CODE_SETTING_TEMPLATE_CHOICES,
        default=settings.MATOMO_TRACKING_CODE_SETTING_TEMPLATE_DEFAULT,
        verbose_name=_('template')
    )
    url = models.URLField(
        max_length=255,
        verbose_name=_('url')
    )
    site_id = models.CharField(
        max_length=255,
        verbose_name=_('site id')
    )

    class Meta:
        verbose_name = _('tracking code setting')
        verbose_name_plural = _('tracking code settings')
        ordering = ('ordering',)
        permissions = (
            ("list_trackingcodesetting", "Can list tracking code setting"),
            ("detail_trackingcodesetting", "Can detail tracking code setting"),
            ("enable_trackingcodesetting", "Can enable tracking code setting"),
            ("disable_trackingcodesetting", "Can disable tracking code setting"),
        )

    def __str__(self):
        return '[{}] {}'.format('ON' if self.status else 'OFF', self.title)


class TagManagerSetting(CMSPlugin, CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    title = models.CharField(
        max_length=255,
        verbose_name=_('title')
    )
    slug = models.SlugField(
        max_length=255,
        verbose_name=_('slug')
    )
    template_name = models.CharField(
        max_length=255,
        choices=settings.MATOMO_TAG_MANAGER_SETTING_TEMPLATE_CHOICES,
        default=settings.MATOMO_TAG_MANAGER_SETTING_TEMPLATE_DEFAULT,
        verbose_name=_('template')
    )
    url = models.URLField(
        max_length=255,
        verbose_name=_('url')
    )
    tag_code = models.CharField(
        max_length=255,
        blank=True, null=True,
        verbose_name=_('tag code')
    )

    class Meta:
        verbose_name = _('tag manager setting')
        verbose_name_plural = _('tag manager settings')
        ordering = ('ordering',)
        permissions = (
            ("list_tagmanagersetting", "Can list tag manager setting"),
            ("detail_tagmanagersetting", "Can detail tag manager setting"),
            ("enable_tagmanagersetting", "Can enable tag manager setting"),
            ("disable_tagmanagersetting", "Can disable tag manager setting"),
        )

    def __str__(self):
        return '[{}] {}'.format('ON' if self.status else 'OFF', self.title)
